@@ -1349,7 +1349,7 @@ class BaseIOSIntfLine(IOSCfgLine):
         ##   default value is True
         for obj in self.children:
             switch = obj.re_match(r"^\s*(switchport\snoneg\S*)\s*$")
-            if not (switch is None):
+            if (switch is not None):
                 return False
         return True
 
@@ -1992,7 +1992,7 @@ class IOSRouteLine(BaseIOSRouteLine):
             self.feature = "ipv6 route"
             self._address_family = "ipv6"
             mm = _RE_IPV6_ROUTE.search(self.text)
-            if not (mm is None):
+            if (mm is not None):
                 self.route_info = mm.groupdict()
             else:
                 raise ValueError("Could not parse '{0}'".format(self.text))
@@ -2000,7 +2000,7 @@ class IOSRouteLine(BaseIOSRouteLine):
             self.feature = "ip route"
             self._address_family = "ip"
             mm = _RE_IP_ROUTE.search(self.text)
-            if not (mm is None):
+            if (mm is not None):
                 self.route_info = mm.groupdict()
             else:
                 raise ValueError("Could not parse '{0}'".format(self.text))
@@ -2013,7 +2013,7 @@ class IOSRouteLine(BaseIOSRouteLine):
 
     @property
     def vrf(self):
-        if not (self.route_info["vrf"] is None):
+        if (self.route_info["vrf"] is not None):
             return self.route_info["vrf"]
         else:
             return ""
@@ -2188,7 +2188,7 @@ class IOSAaaGroupServerLine(BaseCfgLine):
 
         REGEX = r"^aaa\sgroup\sserver\s(?P<protocol>\S+)\s(?P<group>\S+)\s*$"
         mm = re.search(REGEX, self.text)
-        if not (mm is None):
+        if (mm is not None):
             groups = mm.groupdict()
             self.protocol = groups.get("protocol", "")
             self.group = groups.get("group", "")
@@ -2225,7 +2225,7 @@ class IOSAaaGroupServerLine(BaseCfgLine):
         rgx_priv = re.compile(r"^\s+server-private\s+(\S+)\s")
         for cobj in self.children:
             mm = rgx_priv.search(cobj.text)
-            if not (mm is None):
+            if (mm is not None):
                 retval.add(mm.group(1))  # This is the server's ip
         return retval
 
